@@ -18,13 +18,19 @@ function loadAssignmentPage(assignment) {
     }, function () {
         $(this).next("span").removeClass("d-inline-table");
     })
+}
 
+function saveAssignment() {
+    console.log("SAVING ASSIGNMENT");
 }
 
 
 $(document).ready(function () {
     eel.get_assignment()(loadAssignmentPage);
 });
+$(window).bind('beforeunload', function () {
+    saveAssignment()
+});
 
 function populateDocumentWithConfig(config) {
     let output = ""
@@ -43,9 +49,9 @@ function populateDocumentWithConfig(config) {
     }
     for (item of config.filter((i) => i.type === "checkbox")) {
         if (item.value)
-            value = "on";
+            checked = "checked";
         else
-            value = "off";
+            checked = "";
         output += `
             <div class="form-group">
                 <i class="fas fa-info-circle text-primary cfgtooltip"></i><span class="tooltiptext">${item.description}</span>
@@ -56,7 +62,7 @@ function populateDocumentWithConfig(config) {
                         class="custom-control-input"
                         id="${item.original_name}"
                         data-name="${item.original_name}"
-                        value="${value}"
+                        ${checked}
                     />
                     <label class="custom-control-label" for="${item.original_name}"></label>
                 </div>
@@ -667,11 +673,6 @@ outputButton.addEventListener("click", (e) => {
 // File I/O Scripts
 
 
-function saveAssignment() {
-    console.log("SAVING ASSIGNMENT");
-}
-
-
 let exportButton = document.getElementById("export-container");
 
 
